==> eDMA_1.5-1.tar.gz: eDMA/README.md <==
# eDMA
Perform Dynamic Model Averaging with grid search as in [Dangl and Halling (2012)](http://www.sciencedirect.com/science/article/pii/S0304405X12000633) using parallel computing.

[![CRAN](http://www.r-pkg.org/badges/version/eDMA)](https://cran.r-project.org/package=eDMA) 
[![Downloads](http://cranlogs.r-pkg.org/badges/eDMA?color=brightgreen)](http://www.r-pkg.org/pkg/eDMA)
[![Downloads](http://cranlogs.r-pkg.org/badges/grand-total/eDMA?color=brightgreen)](http://www.r-pkg.org/pkg/eDMA)
[![Pending Pull-Requests](http://githubbadges.herokuapp.com/LeopoldoCatania/eDMA/pulls.svg?style=flat)](https://github.com/LeopoldoCatania/eDMA/pulls)
[![Github Issues](http://githubbadges.herokuapp.com/LeopoldoCatania/eDMA/issues.svg)](https://github.com/LeopoldoCatania/eDMA/issues)

`eDMA` ([Catania and Nonejad, 2016](https://CRAN.R-project.org/package=eDMA)) implements the Dynamic Model Averaging (DMA) estimation technique of 
[Raftery, Karny, and Ettler (2010)](http://www.tandfonline.com/doi/abs/10.1198/TECH.2009.08104) with the modifications of [Dangl and Halling (2012)](http://www.sciencedirect.com/science/article/pii/S0304405X12000633) in R.


The latest stable version of `eDMA` is available at 'https://CRAN.R-project.org/package=eDMA'.

The latest development version of `GASeDMA is available at 'https://github.com/LeopoldoCatania/eDMA'.

Please cite `eDMA` in publications:

Catania, L. and Nonejad, N. (2017). 
_eDMA: Dynamic Model Averaging with Grid Search_.
R package.
[https://CRAN.R-project.org/package=eDMA](https://CRAN.R-project.org/package=eDMA)  

Catania, L., and Nonejad, N. (2016). 
Dynamic Model Averaging for Practitioners in Economics and Finance: The eDMA Package. 
arXiv preprint [arXiv:1606.05656](https://arxiv.org/abs/1606.05656)

==> eDMA_1.5-4.tar.gz: eDMA/README.md <==
# eDMA
Perform Dynamic Model Averaging with grid search as in [Dangl and Halling (2012)](http://www.sciencedirect.com/science/article/pii/S0304405X12000633) using parallel computing.

[![CRAN](http://www.r-pkg.org/badges/version/eDMA)](https://cran.r-project.org/package=eDMA) 
[![Downloads](http://cranlogs.r-pkg.org/badges/eDMA?color=brightgreen)](https://www.r-pkg.org:443/pkg/eDMA)
[![Downloads](http://cranlogs.r-pkg.org/badges/grand-total/eDMA?color=brightgreen)](https://www.r-pkg.org:443/pkg/eDMA)
[![Pending Pull-Requests](http://githubbadges.herokuapp.com/LeopoldoCatania/eDMA/pulls.svg?style=flat)](https://github.com/LeopoldoCatania/eDMA/pulls)
[![Github Issues](http://githubbadges.herokuapp.com/LeopoldoCatania/eDMA/issues.svg)](https://github.com/LeopoldoCatania/eDMA/issues)

`eDMA` ([Catania and Nonejad, 2016](https://CRAN.R-project.org/package=eDMA)) implements the Dynamic Model Averaging (DMA) estimation technique of 
[Raftery, Karny, and Ettler (2010)](http://www.tandfonline.com/doi/abs/10.1198/TECH.2009.08104) with the modifications of [Dangl and Halling (2012)](http://www.sciencedirect.com/science/article/pii/S0304405X12000633) in R.

The latest stable version of `eDMA` is available at 'https://CRAN.R-project.org/package=eDMA'.

Please cite `eDMA` in publications:

Catania, L. and Nonejad, N. (2017). 
_eDMA: Dynamic Model Averaging with Grid Search_.
R package.
[https://CRAN.R-project.org/package=eDMA](https://CRAN.R-project.org/package=eDMA)  

Catania, L., and Nonejad, N. (2016). 
Dynamic Model Averaging for Practitioners in Economics and Finance: The eDMA Package. Journal of Statistical Software, 84(11), 1–39. [https://doi.org/10.18637/jss.v084.i11](https://doi.org/10.18637/jss.v084.i11)
